#
# Copyright 2020-2021 Xilinx, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#!/bin/bash

# This script accepts an 8-bit, YUV420, pre-encoded h264 file and will send the rotated, encoded h.264 output to /tmp/xil_rotate_<N>.mp4 at a rate of 8Mbps.


# method  property enumeration:
# video-direction     : Video direction: rotation and flipping
#                      flags: readable, writable, controllable
#                        Enum "GstVideoOrientationMethod" Default: 0, "identity"
#                          (0): identity         - GST_VIDEO_ORIENTATION_IDENTITY
#                          (1): 90r              - GST_VIDEO_ORIENTATION_90R
#                          (2): 180              - GST_VIDEO_ORIENTATION_180
#                          (3): 90l              - GST_VIDEO_ORIENTATION_90L
#                          (4): horiz            - GST_VIDEO_ORIENTATION_HORIZ
#                          (5): vert             - GST_VIDEO_ORIENTATION_VERT
#                          (6): ul-lr            - GST_VIDEO_ORIENTATION_UL_LR
#                          (7): ur-ll            - GST_VIDEO_ORIENTATION_UR_LL


if [ $# -ne 3 ]
  then
    echo "Incorrect arguments supplied"
    echo "Usage: ./01_rotate_video.sh <device index> <1080p60 h264 clip> <direction {0..7}>"
    exit 1
fi

#check if the input stream is compatiable with this script
codec_type=`gst-discoverer-1.0 "$2" | grep "video #" | cut -d":" -f2 | awk '{print $1;}'`
echo $codec_type
if [ "$codec_type" != "H.264" ]; then
    echo "This script only supports H.264 input"
    exit -1
fi

di=$1
INPUT=$2
DIRECTION=$3



pipe="gst-launch-1.0 -v filesrc location=$INPUT ! parsebin ! h264parse ! ama_h264dec device=$di ! ama_download device=$di ! video/x-raw, format=I420 ! videoflip video-direction=${DIRECTION} ! ama_upload device=$di ! ama_h264enc device=$di bitrate=8000000 ! h264parse ! qtmux ! fpsdisplaysink video-sink=\"filesink location=/tmp/xil_rotate_${DIRECTION}.mp4\" sync=false text-overlay=false"

$pipe

